Function asnfuzzgen_codecs::uper::encode::encode_integer

source ·
pub fn encode_integer(
    data: &mut PerCodecData,
    lb: Option<i128>,
    ub: Option<i128>,
    is_extensible: bool,
    value: i128,
    extended: bool,
) -> Result<(), PerCodecError>
Encode an INTEGER

This API is also used by other encode functions to encode an integer value.

Note: The maximum (and minimum) value to be decoded is limited to an i128 value. For the protocols that are currently supported this limit is acceptable.